#!/usr/bin/env python
##############################################################################
#
# pyobjcryst        Complex Modeling Initiative
#                   (c) 2015 Brookhaven Science Associates
#                   Brookhaven National Laboratory.
#                   All rights reserved.
#
# File coded by:    Pavol Juhas
#
# See AUTHORS.txt for a list of people who contributed.
# See LICENSE.txt for license information.
#
##############################################################################

"""Python wrapping of ScatteringData class.

See the online ObjCryst++ documentation (https://objcryst.readthedocs.io).
"""

__all__ = ["ScatteringData"]

from pyobjcryst._pyobjcryst import ScatteringData
